@@ -36,7 +36,7 @@ __status__ = "Development"
 #  * Science System (HCSS), also under GPL3.
 #  *
 #  *    2003 - 2014 Do Kester, SRON (JAVA code)
-#  *    2016 - 2017 Do Kester
+#  *    2016 - 2020 Do Kester
 
 class BaseFitter( object ):
     """
@@ -64,7 +64,7 @@ class BaseFitter( object ):
        only exact for linear models with a fixed scale.
     2. Attributes labelled as read only should not be set by a user.
 
-    Category:    Mathematics/Fitting
+    Author: Do Kester
 
     Attributes
     ----------
@@ -76,6 +76,8 @@ class BaseFitter( object ):
         length of the xdata vector(s)
     ndim : int (read only)
         number of xdata vectors
+    weights : array_like
+        the weights on the data from the last fit
     imageAssistant : ImageAssistant
         to convert images to pixels indices, needed for a fit
     keep : dict of {int : float}
@@ -94,9 +96,6 @@ class BaseFitter( object ):
     design : matrix (read only)
         the design matrix (partial of model to parameters)
         returns self.getDesign()
-    hessian : matrix (read only)
-        the hessian matrix
-        returns self.getHessian()
 
     Attributes (available after a call to fit())
     ----------
@@ -111,6 +110,8 @@ class BaseFitter( object ):
     stdevs, standardDeviations : array_like (read only)
         the standard deviations on the parameters
         returns self.getStandardDeviations()
+    hessian : matrix (read only)
+        the hessian matrix
     covariance : matrix (read only)
         the covariance matrix
         returns self.getCovarianceMatrix()
@@ -157,7 +158,7 @@ class BaseFitter( object ):
         keep : dict of {int:float}
             dictionary of indices (int) to be kept at a fixed value (float)
             The values of keep will be used by the Fitter as long as the Fitter exists.
-            See also `fit( ..., keep=dict )`
+            See also fit( ..., keep=dict )
         fixedScale : None or float
             None : the noise scale is not fixed
             float: value of the fixed noise scale
@@ -168,7 +169,7 @@ class BaseFitter( object ):
         ValueError when one of the following is true
             1. Dimensionality of model and input does not match.
             2. Nans in input stream.
-            3. Model is not the head if the compound model chain.
+            3. Model is not the head of a compound model chain.
 
         """
         if model != model._head:
@@ -204,8 +205,7 @@ class BaseFitter( object ):
     def setMinimumScale( self, scale=0 ) :
         """
         Introduce a minimum in scale calculation and consequently in chisq.
-        .. math::
-            \chi^2 >= sumwgt * scale^2
+            chi^2 >= sumwgt * scale^2
 
         Parameters
         ----------
@@ -244,6 +244,8 @@ class BaseFitter( object ):
             if weights is not None :
                 weights = self.imageAssistant.getydata( weights )
 
+        self.weights = weights
+
         if keep is not None :
             return ( self.keepFixed( keep ), ydata, weights )
 
@@ -430,6 +432,20 @@ class BaseFitter( object ):
         raise NotImplementedError( "BaseFitter is a base class, not suitable itself to perform fits." )
 
     def checkNan( self, ydata, weights=None ):
+        """
+        Check there are no Nans or Infs in ydata or weights.
+
+        Parameters
+        ----------
+        ydata : array_like
+            data to be fitted.
+        weights : array_like
+            weights pertaining to ydata
+
+        Raises
+        ------
+        ValueError.
+        """
         if not numpy.all( numpy.isfinite( ydata ) ) :
             raise ValueError( "Fitter: NaNs or Infs in ydata" )
         if  weights is not None and not numpy.all( numpy.isfinite( weights ) ) :
@@ -444,10 +460,14 @@ class BaseFitter( object ):
         name : string
             name of the attribute
         """
-        if name in ['logOccam', 'logLikelihood', 'chisq', 'sumwgt'] :
+        if name in ['logOccam', 'logLikelihood', 'chisq'] :
             raise AttributeError( str( self ) + ": " + name + " is not yet available." )
         elif name == 'parameters' :
             return self.model.parameters
+        elif name == 'weights' :            ## not present return None
+            return None
+        elif name == 'sumwgt' :             ## not present return nxdata
+            return self.nxdata
         elif name == 'yfit' :
             yfit = self.model.result( self.xdata )
             return yfit if self.imageAssistant is None else self.imageAssistant.resizeData( yfit )
@@ -462,7 +482,8 @@ class BaseFitter( object ):
         elif name == 'scale' :
             return self.getScale()
         elif name == "stdevScale" :
-            return self.scale / math.sqrt( 2 * self.nxdata )
+            return self.scale / math.sqrt( 2 * self.sumwgt )
+#            return self.scale / math.sqrt( 2 * self.nxdata )
         elif name == 'evidence' :
             return self.getEvidence()
         elif name == 'logZ' :
@@ -478,7 +499,7 @@ class BaseFitter( object ):
         """
         Return the &beta;-vector.
 
-        It includes `normalized` data if present. See `normalize()`.
+        It includes "normalized" data if present. See normalize().
 
         Parameters
         ----------
@@ -500,7 +521,7 @@ class BaseFitter( object ):
         """
         Calculates the hessian matrix for a given set of model parameters.
 
-        It includes `normalized` data if present. See `normalize()`
+        It includes "normalized" data if present. See normalize()
 
         Parameters
         ----------
@@ -513,6 +534,8 @@ class BaseFitter( object ):
 
         """
         if params is None : params = self.model.parameters
+        if weights is None : weights = self.weights
+
         self.sumwgt = self.nxdata if weights is None else numpy.sum( weights )
 
         if self.model.isNullModel() :
@@ -528,11 +551,11 @@ class BaseFitter( object ):
         design = design.transpose()
 
         if weights is not None :
-            hessian = numpy.inner( design, design * weights )
+            self.hessian = numpy.inner( design, design * weights )
         else :
-            hessian = numpy.inner( design, design )
+            self.hessian = numpy.inner( design, design )
 
-        return hessian
+        return self.hessian
 
 #      * TBD Condition number see Wikipedia: Condition Number and Matrix Norm
 
@@ -570,9 +593,9 @@ class BaseFitter( object ):
     def makeVariance( self, scale=None ):
         """
         Return the (calculated) variance of the remaining noise. I.e.
-            :math:`var = chisq / dof`
+            var = chisq / dof
         when automatic noise scaling is requested or
-            :math:`var = scale^2`
+            var = scale^2
         when we have a fixed scale.
 
         Parameters
@@ -687,8 +710,7 @@ class BaseFitter( object ):
         """
         Calculates of standard deviations pertaining to the parameters.
 
-        .. math::
-            \sigma_i = s * \sqrt( C_{i,i} )
+            &sigma;_i = s * sqrt( C[i,i] )
 
         where C is the Covariance matrix, the inverse of the Hessian Matrix and
         s is the noiseScale.
@@ -713,7 +735,7 @@ class BaseFitter( object ):
     #  *****MONTE CARLO ERROR***************************************************
     def monteCarloError( self, xdata=None, monteCarlo=None):
         """
-        Calculates :math:\sigma:math:-confidence regions on the model given some inputs.
+        Calculates &sigma;-confidence regions on the model given some inputs.
 
         From the full covariance matrix (inverse of the Hessian) random
         samples are drawn, which are added to the parameters. With this new
@@ -747,8 +769,16 @@ class BaseFitter( object ):
         float : the noise scale
             scale = sqrt( chisq / DOF )
 
+        Raise
+        -----
+        RuntimeError when DoF <= 0. The number of (weighted) datapoints is too small.
+
         """
-        dof = self.nxdata - self.npfit
+#        dof = self.nxdata - self.npfit
+        dof = self.sumwgt - self.npfit
+        if dof <= 0 :
+            raise RuntimeError( "More parameters than (weighted) data points" )
+
         return math.sqrt( self.chisq / dof )
 
     #  *****EVIDENCE************************************************************
@@ -756,8 +786,7 @@ class BaseFitter( object ):
         """
         Calculation of the evidence, log10( Z ), for the model given the data.
 
-        ../math::
-            E = \log10( P( Model | data ) )
+            E = log10( P( Model | data ) )
 
         The calculation of the evidence uses a Gaussion approximation of the Posterior
         probability.
@@ -799,8 +828,7 @@ class BaseFitter( object ):
         """
         Calculation of the evidence, log( Z ), for the model given the data.
 
-        .. math::
-            logZ = \log( P( Model | data ) )
+            logZ = log( P( Model | data ) )
 
         The calculation of the evidence uses a Gaussion approximation of the Posterior
         probability.
@@ -819,8 +847,13 @@ class BaseFitter( object ):
         ------
         ValueError when no Prior is available
 
+        RuntimeError when DoF <= 0. The number of (weighted) datapoints is too small.
+
         """
-        dof = self.nxdata - self.npfit
+#        dof = self.nxdata - self.npfit
+        dof = self.sumwgt - self.npfit
+        if dof <= 0 :
+            raise RuntimeError( "More parameters than (weighted) data points" )
 
         if noiseLimits is not None :
             scalerange = math.log( noiseLimits[1] ) - math.log( noiseLimits[0] )
@@ -910,19 +943,3 @@ class BaseFitter( object ):
                 fitter=fitter, residuals=residuals )
 
 
-    def plotResultXXX( self, xdata, ydata, model ) :
-
-        plt.figure( "Fitter Result" )
-        plt.plot( xdata, ydata, 'k,' )
-
-        xx = numpy.linspace( numpy.min( xdata ), numpy.max( xdata ), 1001 )
-
-        yy = model.result( xx )
-        err = self.monteCarloError( xx )
-
-        plt.plot( xx, yy + err, 'r--' )
-        plt.plot( xx, yy - err, 'r--' )
-
-        plt.plot( xx, yy, 'r-' )
-
-        plt.show( )
