@@ -27,27 +27,23 @@ __status__ = "Development"
 #  * Science System (HCSS), also under GPL3.
 #  *
 #  *    2010 - 2014 Do Kester, SRON (Java code)
-#  *    2017 - 2018 Do Kester
+#  *    2017 - 2020 Do Kester
 
 class Engine( object ):
     """
     Engine defines common properties of all Engines.
 
-    An Engine moves around a sample in a random way such that its likelood
+    An Engine moves around a walker in a random way such that its likelood
     remain above the low-likelihood-limit.
 
     Attributes
     ----------
     walkers : WalkerList
-        walkers to be diffused
+        list of walkers to be diffused
     errdis : ErrorDistribution
         error distribution to be used
-    constrain : None or callable (TBD -- future extension)
-        Impose constraints on the parameters.
-        None : no constraints
-        callable : a method as
-            parameters = constrain( model, parameters, xdata )
-        It is the callers responsibility to return valid values for the parameters.
+    slow : int
+        If slow > 0, run this engine every slow-th iteration.
     maxtrials : int
         maximum number of trials for various operations
     rng : numpy.random.RandomState
@@ -73,8 +69,7 @@ class Engine( object ):
 
     #  *********CONSTRUCTORS***************************************************
 
-#    def __init__( self, walkers, errdis, copy=None, seed=4213, constrain=None ):
-    def __init__( self, walkers, errdis, copy=None, seed=4213, verbose=0 ):
+    def __init__( self, walkers, errdis, slow=None, copy=None, seed=4213, verbose=0 ):
         """
         Constructor.
 
@@ -84,15 +79,12 @@ class Engine( object ):
             walkers to be diffused
         errdis : ErrorDistribution
             error distribution to be used
+        slow : None or int > 0
+            Run this engine every slow-th iteration. None for all.
         seed : int
             for random number generator
         verbose : int
             report about the engines when verbose > 4
-        constrain : None or callable (TBD)
-            Impose constraints on the parameters
-            None : no constraints
-            callable : a method as
-                parameters = constrain( model, parameters, xdata )
         copy : Engine
             engine to be copied
 
@@ -107,19 +99,14 @@ class Engine( object ):
             self.unitRange = None
             self.unitMin = None
             self.verbose = verbose
-
-
-#            if constrain is None or callable( constrain ) :
-#                self.constrain = constrain
-#            else :
-#                raise ValueError( "Constrain does not seem callable" )
+            if slow is not None : self.slow = slow
         else :
             self.maxtrials = copy.maxtrials
             self.rng = copy.rng
-#            self.constrain = copy.constrain
             self.unitRange = copy.unitRange
             self.unitMin   = copy.unitMin
             self.verbose   = copy.verbose
+            if hasattr( copy, "slow" ) : self.slow = copy.slow
 
     def copy( self ):
         """ Return a copy of this engine.  """
