@@ -1,6 +1,7 @@
 import numpy as numpy
 from . import Tools
 from .Formatter import formatter as fmt
+from .Formatter import fma
 
 from .Engine import Engine
 
@@ -30,7 +31,7 @@ __status__ = "Development"
 #  * Science System (HCSS), also under GPL3.
 #  *
 #  *    2010 - 2014 Do Kester, SRON (Java code)
-#  *    2017 - 2018 Do Kester
+#  *    2017 - 2020 Do Kester
 
 class GibbsEngine( Engine ):
     """
@@ -42,7 +43,7 @@ class GibbsEngine( Engine ):
 
     """
     #  *********CONSTRUCTORS***************************************************
-    def __init__( self, walkers, errdis, copy=None, seed=4213, verbose=0 ):
+    def __init__( self, walkers, errdis, slow=None, copy=None, seed=4213, verbose=0 ):
         """
         Constructor.
 
@@ -52,13 +53,15 @@ class GibbsEngine( Engine ):
             walkers to be diffused
         errdis : ErrorDistribution
             error distribution to be used
+        slow : None or int > 0
+            Run this engine every slow-th iteration. None for all.
         copy : GibbsEngine
             to be copied
         seed : int
             for random number generator
 
         """
-        super( ).__init__( walkers, errdis, copy=copy, seed=seed, verbose=verbose )
+        super( ).__init__( walkers, errdis, slow=slow, copy=copy, seed=seed, verbose=verbose )
 
     def copy( self ):
         """ Return copy of this.  """
@@ -94,6 +97,14 @@ class GibbsEngine( Engine ):
         perm = self.rng.permutation( fitIndex )
         ur = self.unitRange * ( 1 + 2.0 / len( self.walkers ) )
 
+        param = walker.allpars
+        if self.verbose > 4 :
+            print( "alpar ", fma( param ), fmt( walker.logL ), fmt( lowLhood) )
+            fip = param[fitIndex]
+            print( "uap   ", fma( self.domain2Unit( problem, fip, fitIndex )))
+            print( "fitin ", fma( fitIndex ), self.maxtrials )
+            print( "unitr ", fma( self.unitRange ) )
+
         Lbest = self.walkers[-1].logL
         t = 0
         for c in perm :
@@ -114,6 +125,9 @@ class GibbsEngine( Engine ):
 
                 Ltry = self.errdis.updateLogL( problem, param, parval={c : save} )
 
+                if self.verbose > 4 :
+                    print( "Gibbs ", fma(param), fmt(Ltry), kk, fmt( step ) )
+
                 if Ltry >= lowLhood:
                     self.reportSuccess( )
                     self.setWalker( walker, problem, param, Ltry, fitIndex=fitIndex )
